.. currentmodule:: sqlalchemy.orm

.. _relationship_config_toplevel:

Relationship Configuration
==========================

This section describes the :func:`relationship` function and in depth discussion
of its usage.   For an introduction to relationships, start with the
:ref:`ormtutorial_toplevel` and head into :ref:`tutorial_orm_related_objects`.

.. toctree::
    :maxdepth: 3

    basic_relationships
    self_referential
    join_conditions
    collections
    relationship_persistence
    backref
    relationship_api

